@@ -841,12 +841,21 @@ static int write_dict(bson_buffer* buffer, PyObject* dict, unsigned char check_k
             }
         }
     } else {
-        PyObject* errmsg = PyString_FromString("encoder expected a mapping type but got: ");
-        PyObject* repr = PyObject_Repr(dict);
-        PyString_ConcatAndDel(&errmsg, repr);
-        PyErr_SetString(PyExc_TypeError, PyString_AsString(errmsg));
-        Py_DECREF(errmsg);
-        return 0;
+        /* Try a reload! */
+        _reload_python_objects();
+        if (PyObject_IsInstance(dict, SON)) {
+            if (!write_son(buffer, dict, start_position, length_location, check_keys, top_level)) {
+                return 0;
+            }
+        }
+        else {
+            PyObject* errmsg = PyString_FromString("encoder expected a mapping type but got: ");
+            PyObject* repr = PyObject_Repr(dict);
+            PyString_ConcatAndDel(&errmsg, repr);
+            PyErr_SetString(PyExc_TypeError, PyString_AsString(errmsg));
+            Py_DECREF(errmsg);
+            return 0;
+        }
     }
 
     /* write null byte and fill in length */
@@ -920,6 +929,7 @@ static PyObject* _cbson_insert_message(PyObject* self, PyObject* args) {
     char* collection_name = NULL;
     int collection_name_length;
     PyObject* docs;
+    int list_length;
     int i;
     unsigned char check_keys;
     unsigned char safe;
@@ -960,7 +970,15 @@ static PyObject* _cbson_insert_message(PyObject* self, PyObject* args) {
 
     PyMem_Free(collection_name);
 
-    for (i = 0; i < PyList_Size(docs); i++) {
+    list_length = PyList_Size(docs);
+    if (list_length <= 0) {
+        PyObject* InvalidOperation = _error("InvalidOperation");
+        PyErr_SetString(InvalidOperation, "cannot do an empty bulk insert");
+        Py_DECREF(InvalidOperation);
+        buffer_free(buffer);
+        return NULL;
+    }
+    for (i = 0; i < list_length; i++) {
         PyObject* doc = PyList_GetItem(docs, i);
         if (!write_dict(buffer, doc, check_keys, 1)) {
             buffer_free(buffer);
