@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,11 +23,14 @@ import calendar
 
 from pymongo.binary import Binary
 from pymongo.code import Code
-from pymongo.objectid import ObjectId
 from pymongo.dbref import DBRef
+from pymongo.errors import (InvalidBSON,
+                            InvalidDocument,
+                            InvalidName,
+                            InvalidStringData)
+from pymongo.objectid import ObjectId
 from pymongo.son import SON
-from pymongo.errors import InvalidBSON, InvalidDocument
-from pymongo.errors import InvalidName, InvalidStringData
+from timestamp import Timestamp
 
 try:
     import _cbson
@@ -324,9 +327,9 @@ def _get_ref(data):
 
 
 def _get_timestamp(data):
-    (timestamp, data) = _get_int(data)
     (inc, data) = _get_int(data)
-    return ((timestamp, inc), data)
+    (timestamp, data) = _get_int(data)
+    return (Timestamp(timestamp, inc), data)
 
 def _get_long(data):
     return (struct.unpack("<q", data[:8])[0], data[8:])
@@ -445,6 +448,10 @@ def _element_to_bson(key, value, check_keys):
         millis = int(calendar.timegm(value.timetuple()) * 1000 +
                      value.microsecond / 1000)
         return "\x09" + name + struct.pack("<q", millis)
+    if isinstance(value, Timestamp):
+        time = struct.pack("<i", value.time)
+        inc = struct.pack("<i", value.inc)
+        return "\x11" + name + inc + time
     if value is None:
         return "\x0A" + name
     if isinstance(value, _RE_TYPE):
@@ -543,17 +550,7 @@ class BSON(str):
     Represents binary data storable in and retrievable from Mongo.
     """
 
-    def __new__(cls, bson):
-        """Initialize a new :class:`BSON` instance with some data.
-
-        Raises :class:`TypeError` if `bson` is not an instance of
-        :class:`str`.
-
-        :Parameters:
-          - `bson`: the initial data
-        """
-        return str.__new__(cls, bson)
-
+    @classmethod
     def from_dict(cls, dct, check_keys=False):
         """Create a new :class:`BSON` instance from a mapping type
         (like :class:`dict`).
@@ -570,7 +567,6 @@ class BSON(str):
             in either case
         """
         return cls(_dict_to_bson(dct, check_keys))
-    from_dict = classmethod(from_dict)
 
     def to_dict(self):
         """Get the dictionary representation of this data."""
