@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 
 """Tools for manipulating DBRefs (references to MongoDB documents)."""
 
-from son import SON
+from pymongo.son import SON
 
 
 class DBRef(object):
@@ -35,6 +35,8 @@ class DBRef(object):
 
         .. versionadded:: 1.1.1
            The `database` parameter.
+
+        .. mongodoc:: dbrefs
         """
         if not isinstance(collection, basestring):
             raise TypeError("collection must be an instance of basestring")
@@ -45,18 +47,19 @@ class DBRef(object):
         self.__id = id
         self.__database = database
 
+    @property
     def collection(self):
         """Get the name of this DBRef's collection as unicode.
         """
         return self.__collection
-    collection = property(collection)
 
+    @property
     def id(self):
         """Get this DBRef's _id.
         """
         return self.__id
-    id = property(id)
 
+    @property
     def database(self):
         """Get the name of this DBRef's database.
 
@@ -65,7 +68,6 @@ class DBRef(object):
         .. versionadded:: 1.1.1
         """
         return self.__database
-    database = property(database)
 
     def as_doc(self):
         """Get the SON document representation of this DBRef.
