@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -51,6 +51,8 @@ class OperationFailure(PyMongoError):
 class DuplicateKeyError(OperationFailure):
     """Raised when a safe insert or update fails due to a duplicate key error.
 
+    .. note:: Requires server version **>= 1.3.0**
+
     .. versionadded:: 1.4
     """
 
@@ -88,3 +90,10 @@ class InvalidDocument(PyMongoError):
 class InvalidId(PyMongoError):
     """Raised when trying to create an ObjectId from invalid data.
     """
+
+
+class InvalidURI(PyMongoError):
+    """Raised when trying to parse an invalid mongodb URI.
+
+    .. versionadded:: 1.5
+    """
