@@ -34,6 +34,7 @@ from pymongo.collection import Collection
 from pymongo.errors import (DuplicateKeyError,
                             InvalidDocument,
                             InvalidName,
+                            InvalidOperation,
                             OperationFailure)
 from pymongo.objectid import ObjectId
 from pymongo.son import SON
@@ -437,6 +438,8 @@ class TestCollection(unittest.TestCase):
         self.assert_(isinstance(id, list))
         self.assertEqual(1, len(id))
 
+        self.assertRaises(InvalidOperation, db.test.insert, [])
+
     def test_insert_iterables(self):
         db = self.db
 
@@ -956,5 +959,10 @@ class TestCollection(unittest.TestCase):
         db[u"Employés"].find_one()
         list(db[u"Employés"].find())
 
+    def test_drop_indexes_non_existant(self):
+        self.db.drop_collection("test")
+        self.db.test.drop_indexes()
+
+
 if __name__ == "__main__":
     unittest.main()
